BubleClient class final

Constructors

BubleClient({String? apiKey, Uri? baseUrl, Duration timeout = const Duration(seconds: 60), Map<String, String> headers = const {}, Client? httpClient, Map<String, String>? environment})
BubleClient.fromEnvironment({Duration timeout = const Duration(seconds: 60), Map<String, String> headers = const {}, Client? httpClient})
BubleClient.fromOptions(BubleClientOptions options)

Properties

apps AppsResource
final
chat ChatResource
final
files FilesResource
final
generations GenerationsResource
final
hashCode int
The hash code for this object.
no setterinherited
mediaModels MediaModelsResource
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited