CreateGenerationRequest class final

Constructors

CreateGenerationRequest({required String model, String? mode, String? prompt, List<String>? imageUrls, String? startFrame, String? endFrame, List<String>? videoUrls, List<String>? audioUrls, bool? isPublic, bool? copyProtected, Map<String, Object?>? parameters})

Properties

audioUrls List<String>
final
copyProtected bool?
final
endFrame String?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrls List<String>
final
isPublic bool?
final
mode String?
final
model String
final
parameters Map<String, Object?>
final
prompt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startFrame String?
final
videoUrls List<String>
final

Methods

copyWith({String? model, String? mode, String? prompt, List<String>? imageUrls, String? startFrame, String? endFrame, List<String>? videoUrls, List<String>? audioUrls, bool? isPublic, bool? copyProtected, Map<String, Object?>? parameters}) CreateGenerationRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() JsonMap
toString() String
A string representation of this object.
inherited
withParam(String key, Object? value) CreateGenerationRequest
withParams(Map<String, Object?> values) CreateGenerationRequest

Operators

operator ==(Object other) bool
The equality operator.
inherited