GenerationResult class final

Constructors

GenerationResult({List<MediaResultImage> images = const [], List<MediaResultVideo> videos = const [], List<MediaResultAudio> audios = const [], JsonMap raw = const {}})
const
GenerationResult.fromJson(JsonMap json)
factory

Properties

audios → List<MediaResultAudio>
final
hashCode → int
The hash code for this object.
no setterinherited
images → List<MediaResultImage>
final
raw → JsonMap
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videos → List<MediaResultVideo>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited