MediaResultImage class final

Constructors

MediaResultImage({required Uri url, JsonMap raw = const {}})
const
MediaResultImage.fromJson(JsonMap json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
raw → JsonMap
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited