UploadOptions class final

Constructors

UploadOptions({String? fileType, String? model, String? mode})
const

Properties

fileType String?
final
hashCode int
The hash code for this object.
no setterinherited
mode String?
final
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFields() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited