MediaModelParameter class final
Constructors
- MediaModelParameter({required String name, String? type, String? label, Object? defaultValue, JsonList? values, bool? required, JsonMap raw = const {}})
-
const
- MediaModelParameter.fromJson(JsonMap json)
-
factory
Properties
- defaultValue → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- name → String
-
final
- raw → JsonMap
-
final
- required → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
- values → JsonList?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited