PublicApp class final
Constructors
-
PublicApp({required String id, List<
AppInputParameter> inputParameters = const [], JsonMap raw = const {}}) -
const
- PublicApp.fromJson(JsonMap json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
inputParameters
→ List<
AppInputParameter> -
final
- raw → JsonMap
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited